function y = lorentz_parfun(params, x)
% y = lorentz_parfun(params, x)
%
% Evaluate a sum of Lorentzians defined through the params array at x.
%
% Each row of 'params' has length 3 with the following meaning:
%
%   params(:,1)  --  x0, the base point
%   params(:,2)  --  gamma, the half-width at half height
%   params(:,3)  --  I, the intensity
%
% See also: lorentz

[num_l, n] = size(params);
assert(n==3);

y = zeros(size(x));

for k=1:num_l
    x0 = params(k,1);
    gamma = params(k,2);
    I = params(k,3);

    f = lorentz(x0,gamma,I);
    y = y + f(x);
end

end