function sepstats(H, norm_flag)
% Measure distance to separability in the H factor of the factorization M =
% W*H.

assert(all(H(:) >= 0));

if nargin < 3 || isempty(norm_flag)
    norm_flag = 1;
end

[r,n] = size(H);
d = sum(H);
Hs = H * diag(1.0 ./ d);

char_idx = zeros(r,1);

for k=1:r
    target = zeros(r,1);
    target(k) = 1;
    best_val = inf;
    best_idx = -1;
    for j=1:n
        res = norm(target - Hs(:,j), norm_flag);
        if res < best_val
            best_val = res;
            best_idx = j;
        end
    end
    char_idx(k) = best_idx;
end

Hs_noise = norm(Hs(:,char_idx) - eye(r));
fprintf('Normwise distance to separability in Hs: %.2e\n', Hs_noise);

end
