# -*- coding: utf-8 -*-
"""
Created on Wed Sep 22 12:39:14 2021

@author: R.Sechi
This notebook returns a set of artificial data as in 
doi: 10.1177/0003702816662600


"""
import numpy as np
from gendata import gendata
import matplotlib.pyplot as plt



def artdata(sep, noise_level):
    """# % Generate 5 species example data
    'sep' value in [0,1], 0 means no separation at all, 1 reasonable
        separation
     'noise_level'  relative noise level added to data
     
     For Python version:
         Input: sep = float, [0,1]
                noise_level = float, [0,1]
        Output:
            Mtilde= matrix with time-resolved Raman specturm
            W = 2d-array, spectral amplitudes
            H = 2d-array, curves with the concentration proportions
            N = 2d-array, matrix with relative noise level, added to M
            K = 2d-array, transition probability matrix obtained from H
            f = 1d-array, frequencies
            tspan = 2d-array, the time points to each spectrum
            
         """
   # in order to make sure to generate similar data, we are keeping the same
   # K matrix as in Luce's work.
    H = np.loadtxt('C:/Users/renat/Documents/memory-mf-pcca/memory-mf-spectra/PythonData/H.txt')



# if nargin < 2 || isempty(noise_level)
#     noise_level = 0.0;
# end

# if nargin < 1 || isempty(sep)
#     sep = 1.0;
# end

    W, H, K, f, tspan = gendata(sep, H)
# sepstats(W,H); not needed for the purpose of this article

    # tmp = H
    # H = W.T
    # W = tmp
    M = W.dot(H) 
    print (M.shape)
    N = np.random.random(M.shape)
    N = (noise_level / np.linalg.norm(N)) * N * np.linalg.norm(M)
    N = np.abs(N)
    Mtilde = M + N
# this part is here left commented, but present in the original code
#[m_est, s_est] = estimate_noise(Mtilde);
#n1_est = 2 * s_est * length(tspan);

# % Debug output
# fprintf('True noise params: mean %.2f  std %.2f\n', mean(N(:)), std(N(:)));
# fprintf('Est. noise params: mean %.2f  std %.2f\n', m_est, s_est);
# fprintf('Inf-Norm of Noise (true/est): %.2e/%.2e\n', norm(N,inf), n1_est);
# end
    return(Mtilde, W, H, N, K, f, tspan)

