# -*- coding: utf-8 -*-
"""
Created on Mon Sep 27 15:16:00 2021

@author: R.Sechi
This notebook generates the syntethic dataset with no noise nor interference.
Then, the minimal memory effect is computed for the synthetic dataset
for a NMF 5 compounds.
The generated synthetic dataset represents a time-resolved Raman spectrum.
"""
import numpy as np
import matplotlib.pyplot as plt
from artdata import artdata
from method_nmf import nmf
from memory_nmf_new import mme_new
from matplotlib.colors import ListedColormap
import string
import seaborn as sns

#%%1 no noise, no interference
#generates dataset
M, W, H, N, K, f, tspan = artdata(1., 0.)
#uncomment the line below if you want to obtain all the components of the 
#decomposition
#M_r, W_r, H_r, K_r, A_optimized, chi, Uitgm = nmf(M,  r = 5, params = [-0.0001,-1.,1.,0.,0.], weight=False)
#%%
#compute minimal memory effect
detS = mme(M, tspan, f, params= [-0.001,-10.,1.,0.,0.], clus_list=[5])
#%%
#plot of the generated dataset as bidimensional heatmap
plt.figure(figsize=(10,10))
plt.imshow(M.T, aspect="auto")
plt.yticks(np.arange(0,tspan.shape[0], step=20), np.around(tspan[::20],1))
plt.xticks(np.arange(0,f.shape[0], step=300), labels= np.around(f[::300]))
plt.colorbar()
plt.xlabel(r"$\nu$ [cm-1]")
plt.ylabel("time delay [s]")
plt.title("Synthetic Raman spectrum")
#plt.savefig("synthetic_data.pdf")
plt.show()
